@@ -3,6 +3,7 @@ from django.conf import settings
 from actstream.feeds import *
 
 urlpatterns = patterns('actstream.views',
+    # Syndication Feeds
     url(r'^feed/(?P<content_type_id>\d+)/(?P<object_id>\d+)/atom/$', AtomObjectActivityFeed(), name='actstream_object_feed_atom'),
     url(r'^feed/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$', ObjectActivityFeed(), name='actstream_object_feed'),
     url(r'^feed/(?P<content_type_id>\d+)/atom/$', AtomModelActivityFeed(), name='actstream_model_feed_atom'),    
@@ -10,8 +11,13 @@ urlpatterns = patterns('actstream.views',
     url(r'^feed/$', UserActivityFeed(), name='actstream_feed'),
     url(r'^feed/atom/$', AtomUserActivityFeed(), name='actstream_feed_atom'),    
     
+    # Follow/Unfollow API
     url(r'^follow/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$',
-        'follow', name='actstream_follow'),
+        'follow_unfollow', name='actstream_follow'),
+    url(r'^unfollow/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$',
+        'follow_unfollow', {'follow':False}, 'actstream_unfollow'),
+    
+    # Follower and Actor lists
     url(r'^followers/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$',
         'followers', name='actstream_followers'),
     url(r'^actors/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$',
